@@ -3,6 +3,9 @@
   |_) /|  Copyright (C) 2003  |  richard@
   | \/|  Richard Atterer     |  atterer.org
    '` 
+
+  Copyright (C) 2021 Steve McIntyre <steve@einval.com>
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2. See
   the file COPYING for details.
@@ -478,7 +481,7 @@ void GtkSingleUrl::dataSource_dataSize(uint64) {
 }
 //______________________________________________________________________
 
-void GtkSingleUrl::dataSource_data(const byte* /*data*/, unsigned /*size*/,
+void GtkSingleUrl::dataSource_data(const Ubyte* /*data*/, unsigned /*size*/,
                                   uint64 /*currentSize*/) {
   //debug("dataSource_data %1", job->progress()->currentSize());
   if (!needTicks())
